@@ -1,8 +1,9 @@
 import abc
+import simplejson as json
 from enum import Enum
-import json
 from functools import cached_property
 
+from worker.data.json_encoder import JsonEncoder
 from worker.framework import constants
 
 
@@ -52,4 +53,4 @@ class Event(abc.ABC):
             return
 
         payload = self.build_message_producer_payload()
-        api.post(path='/v1/message_producer', data=json.dumps(payload))
+        api.post(path='/v1/message_producer', data=json.dumps(payload, cls=JsonEncoder, ignore_nan=True))
